|Logo|

AMYPAD
======

Amyloid imaging to prevent Alzheimer's Disease.


Install
-------

Choose one of the following:

.. code:: sh

    pip install amypad  # command line interface (CLI) version
    pip install amypad[gui]  # CLI and graphical user interface (GUI) version


Usage
-----

.. code:: sh

    amypad --help  # CLI version
    amypad.gui     # GUI version


.. |Logo| image:: https://amypad.eu/wp-content/themes/AMYPAD/images/AMYPAD_Logo.jpg
   :target: https://amypad.eu
